@@ -10,15 +10,14 @@ class Load(Step.Step):
         self.paramsFile = 'Load.properties'
         self.logger = 'logLoad'
         self.logFile = self.getRelativeFile(os.getcwd() + '\../logs/Load.log')
+        self.preStep= "Ml"
         
-        
-
     def startup(self):
-        super(Load, self).startup()
-        self.startConsensusSubscriber()
+        super(self).startup()
+        self.startSubscriber()
+    
+    def doWork(self):
+        pass
     
         
         
-    def startConsensusSubscriber(self):
-        self.subscriber = self.rC.pubsub()
-        self.subscriber.subscribe(self.taskID + "_" + self.step)
\ No newline at end of file
