@@ -13,20 +13,18 @@ class Ml(Step.Step):
         self.paramsFile = 'ML.properties'
         self.logger = 'logMl'
         self.logFile = self.getRelativeFile(os.getcwd() +'\../logs/Ml.log')
+        self.preStep= "Tr"
 
     def startup(self):
-        super(Ml, self).startup()
-        self.taskExecutionID = None
-        self.startMLSubscriber()
+        super(self).startup()
+        self.startSubscriber()
+
+    def doWorkAndHandoff(self):
+        pass
+
+    def doWork(self):
+        pass
         
-    def startMLSubscriber(self):
-        self.subscriber = self.rC.pubsub()
-        self.subscriber.subscribe(self.taskID + "_" + "Tr")
-
-    
-            
-
-    
     def computeML(self,msg):
         pass   
                 
